" Maintainer:   Laszlo Zavaleta <zavaleta@smartchat.net.au>
" Last Changed: 2003 Aug 08
" it has all the accents and a few of the character alterations

let b:keymap = "magyar"

loadkey
`	í
~	Í
!	'
@	"
#	+
$	!
^	/
&	=
*	(
(	)
0	ö
)	Ö
-	ü
_	Ü
=	ó
+	Ó
\\	ű
|	Ű
[	ő
{	Ő
]	ú
}	Ú
;	é
:	É
'	á
\"	Á
/	-
<	?
>	:
?	_
